#include <iostream>
#include <fstream>
#include <vector>
#include <string>
#include <sstream>

using namespace std;

const int MAX_V = 2005;
const int MAX_E = 3005;

vector<int> adj [MAX_V];
bool vis [MAX_V];
bool reachable [MAX_V][MAX_V];

void dfs (int vertex, int src) {
  vis[vertex] = true;
  reachable[src][vertex / 2] = true;

  for (int nxt : adj[vertex]) {
    if (!vis[nxt]) {
      dfs(nxt, src);
    }
  }
}

pair<bool, string> parse_line (string line) {
  vector<string> tokens;
  istringstream ss (line);
  string token;
  while (ss >> token) {
    tokens.push_back(token);
  }
  if ((int) tokens.size() != 1) {
    return make_pair(false, string());
  }
  return make_pair(true, tokens[0]);
}

int main (int argc, char **argv) {
  ifstream input_file (argv[1]);
  /* ifstream answer_file (argv[2]); */
  ifstream student_file (argv[3]);

  int vertexc, edgec;
  input_file >> vertexc >> edgec;

  vector<string> student_output;
  while (student_file) {
    string str;
    getline(student_file, str);
    student_output.push_back(str);
  }
  student_file.close();

  if (!student_output.empty() && student_output.back().empty()) {
    student_output.pop_back();
  }

  if ((int) student_output.size() != edgec) {
    cerr << "Presentation error: invalid number of lines!" << endl;
    cout << "0.0" << endl;
    input_file.close();
    return 0;
  }

  vector<string> colors;
  for (int i = 0; i < (int) student_output.size(); i++) {
    pair<bool, string> token = parse_line(student_output[i]);
    if (!token.first) {
      cerr << "Presentation error: invalid number of tokens on line " << i + 1 << "!" << endl;
      cout << "0.0" << endl;
      input_file.close();
      return 0;
    }

    if (token.second != "punane" && token.second != "sinine") {
      cerr << "Presentation error: invalid token on line " << i + 1 << ": token is not \"punane\" or \"sinine\"!" << endl;
      cout << "0.0" << endl;
      input_file.close();
      return 0;
    }
    colors.push_back(token.second);
  }
    

  for (int i = 0; i < edgec; i++) {
    int u, v;
    input_file >> u >> v;

    if (colors[i] == string("punane")) {
      adj[2 * u].push_back(2 * v + 1);
      adj[2 * v].push_back(2 * u + 1);
    } else if (colors[i] == string("sinine")) {
      adj[2 * u + 1].push_back(2 * v);
      adj[2 * v + 1].push_back(2 * u);
    }
  }
  input_file.close();

  for (int i = 2; i <= 2 * vertexc + 1; i++) {
    for (int j = 2; j <= 2 * vertexc + 1; j++) {
      vis[j] = false;
    }

    dfs(i, i / 2);
  }

  for (int i = 1; i <= vertexc; i++) {
    for (int j = 1; j <= vertexc; j++) {
      if (!reachable[i][j]) {
        cerr << "Wrong answer: no path from " << i << " to " << j << endl;
        cout << "0.0" << endl;
        return 0;
      }
    }
  }

  cerr << "OK" << endl;
  cout << "1.0" << endl;
}
