#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

const int maxn = 100005;

namespace tree {
  vector<int> adj [2 * maxn];
  int weight [2 * maxn];

  void add_edge (int u, int v) {
    adj[u].push_back(v);
    adj[v].push_back(u);
  }

  int ans;
  int dfs (int vertex, int parent) {
    vector<int> child_dps;
    for (int nxt : adj[vertex]) {
      if (nxt != parent) {
        child_dps.push_back(dfs(nxt, vertex));
      }
    }
    sort(child_dps.begin(), child_dps.end(), greater<int>());

    if ((int) child_dps.size() >= 2) {
      ans = max(ans, child_dps[0] + weight[vertex] + child_dps[1]);
    }

    int cur = weight[vertex];
    if ((int) child_dps.size() >= 1) {
      cur = max(cur, child_dps[0] + weight[vertex]);
    }

    ans = max(ans, cur);
    return cur;
  }

  int heaviest_path () {
    ans = 0;
    dfs(0, 0);
    return ans;
  }
}

namespace graph {
  vector<int> adj [maxn];

  void add_edge (int u, int v) {
    adj[u].push_back(v);
    adj[v].push_back(u);
  }

  int lvl [maxn], low [maxn];
  vector<int> stk;
  int block_count;
  void build_tree (int vertex, int cur_lvl) {
    lvl[vertex] = cur_lvl;
    low[vertex] = lvl[vertex];
    tree::weight[maxn + vertex] = -1;
    stk.push_back(vertex);

    for (int nxt : adj[vertex]) {
      if (lvl[nxt] == 0) {
        build_tree(nxt, lvl[vertex] + 1);
        if (low[nxt] >= lvl[vertex]) {
          int block_size = 1, block_id = block_count;
          block_count++;
          while (stk.back() != nxt) {
            block_size++;
            tree::add_edge(block_id, maxn + stk.back());
            stk.pop_back();
          }
          block_size++;
          tree::add_edge(block_id, maxn + stk.back());
          stk.pop_back();
          tree::add_edge(block_id, maxn + vertex);
          tree::weight[block_id] = block_size;
        }
      }

      if (lvl[nxt] > lvl[vertex]) {
        low[vertex] = min(low[vertex], low[nxt]);
      } else {
        low[vertex] = min(low[vertex], lvl[nxt]);
      }
    }
  }
}

int main () {
  freopen("pakksis.txt", "r", stdin);
  freopen("pakkval.txt", "w", stdout);
  int vertexc, edgec;
  cin >> vertexc >> edgec;

  for (int i = 0; i < edgec; i++) {
    int u, v;
    cin >> u >> v;

    graph::add_edge(u, v);
  }

  for (int i = 1; i <= vertexc; i++) {
    graph::lvl[i] = 0;
  }

  graph::build_tree(1, 1);
  cout << tree::heaviest_path() << endl;
}
