import Data.Int
import Control.Monad
import Data.List

zeta :: [Int64] -> [Int64]
zeta [] = []
zeta [a] = [a]
zeta as = ls' ++ (zipWith (+) ls' rs')
  where
    (ls, rs) = splitAt (length as `div` 2) as
    ls' = zeta ls
    rs' = zeta rs

pad :: Integral a => [a] -> [a]
pad = aux 0 1
  where
    aux i n [] = take (n-i) $ repeat 0
    aux i n (a:as) = a : aux (i+1) (if i == n then n+n else n) as

data KeyVal a b = KeyVal a b
instance Eq a => Eq (KeyVal a b) where
  KeyVal a1 _ == KeyVal a2 _ = a1 == a2
instance Ord a => Ord (KeyVal a b) where
  KeyVal a1 _ `compare` KeyVal a2 _ = a1 `compare` a2

unkv :: [KeyVal a b] -> ([a], [b])
unkv [] = ([], [])
unkv (KeyVal a b:xs) = let (as, bs) = unkv xs in (a:as, b:bs)

sortWrap :: Ord a => ([a] -> [b]) -> [a] -> [b]
sortWrap f as = bs
  where
    (as', ps) = unkv $ sort $ zipWith KeyVal as [0..]
    bs' = f as'
    (_, bs) = unkv $ sort $ zipWith KeyVal ps bs'

select :: [a] -> [Int] -> [a]
select as = sortWrap (aux 0 as)
  where
    aux _ _ [] = []
    aux _ [] _ = undefined -- can't happen
    aux i (a:as) (j:js) = if i == j
      then a : aux i (a:as) js
      else aux (i+1) as (j:js)

solve :: [Int] -> [Int64]
solve (xc:qc:rest) = let (xs, qs) = splitAt xc rest
                   in select (zeta (pad $ map fromIntegral xs)) qs

solveStr :: String -> String
solveStr = unlines . map show . solve . map read . words

main :: IO ()
main = fmap solveStr getContents >>= putStr
