use std::fs::File;
use std::io::*;

struct Lexer {
	buf: Vec<u8>,
	pos: usize,
}

impl Lexer {
	fn new(mut buf: Vec<u8>) -> Lexer {
		buf.push(0);
		return Lexer { buf: buf, pos: 0 };
	}
	fn digit(&self) -> u64 {
		match (self.buf[self.pos] as u64).overflowing_sub(48) {
			(x, _) => x
		}
	}
	fn get_u64(&mut self) -> u64 {
		while self.digit() > 9 {
			self.pos += 1;
		}
		let mut a = 0;
		let mut d = self.digit();
		loop {
			self.pos += 1;
			a = a*10 + d;
			d = self.digit();
			if d > 9 {
				break;
			}
		}
		a
	}
}

struct Dumper {
	buf: Vec<u8>,
}

impl Dumper {
	fn new() -> Dumper { Dumper { buf: vec![] } }
	fn bytes(&self) -> &[u8] { &self.buf[..] }
	fn dump(&mut self, x: u64) {
		if x == 0 {
			self.buf.push(48);
		} else {
			let mut x = x;
			let st = self.buf.len();
			loop {
				self.buf.push((48 + x%10) as u8);
				x /= 10;
				if x == 0 {
					break;
				}
			}
			self.buf[st..].reverse();
		}
		self.buf.push(10);
	}
}

fn main() {
	let mut rfd = File::open("siinsis.txt").unwrap();
	let mut wfd = File::create("siinval.txt").unwrap();
	let mut buf = Vec::new();
	rfd.read_to_end(&mut buf).unwrap();
	let mut lex = Lexer::new(buf);
	let xc = lex.get_u64();
	let qc = lex.get_u64();

	let mut xs = vec![0; 1<<20];
	for i in 0..xc as usize {
		xs[i] = lex.get_u64();
	}

	for k in 0..20 {
		let m: usize = 1<<k;
		for i in 0..xc as usize {
			if i&m != 0 {
				xs[i] += xs[i-m];
			}
		}
	}

	let mut dmp = Dumper::new();
	for _ in 0..qc {
		let q = lex.get_u64() as usize;
		dmp.dump(xs[q]);
		//println!("{}", xs[q]);
	}
	wfd.write(dmp.bytes()).unwrap();
}
