import Control.Monad
import Data.Array.Unboxed
import Data.Int
import Data.Bits

type Vec = UArray Int Int64

roundUp :: Integral n => n -> (n, n)
roundUp = aux 0 1
  where aux w m n = if n <= m then (w, m) else aux (w+1) (m+m) n

zeta :: Vec -> Vec
zeta input_xs = aux n n (listArray (0, n-1) $ map fromIntegral $ elems input_xs)
  where
    (_, n) = roundUp $ let (l,r) = bounds input_xs in r-l+1
    aux :: Int -> Int -> Vec -> Vec
    aux 0 _ xs = xs
    aux m n xs = listArray (0, n-1) $ map f [0..n-1]
      where
        ys = aux (div m 2) n xs
        f i = if i.&.m == 0 then ys!i
                            else ys!i + ys!(i-m)

zeroPad :: [Int] -> [Int]
zeroPad xs = aux xs 0x100000
  where
    aux [] n = take n $ repeat 0
    aux (x:xs) n = x : aux xs (n-1)

solve :: [Int] -> [Int64]
solve (xc:qc:rest) = let (xs, qs) = splitAt xc rest
                   in map (zeta (listArray (0, 0xfffff) $ map fromIntegral (zeroPad xs))  !) qs

solveStr :: String -> String
solveStr = unlines . map show . solve . map read . words

main :: IO ()
main = fmap solveStr getContents >>= putStr
