#include <iostream>
#include <fstream>
#include <string>
#include <vector>
#include <map>
#include <algorithm>
#include <cassert>
#include <cstdio>
using namespace std;

ifstream fi("ultrasis.txt");
ofstream fo("ultraval.txt");

vector<string> split(string s, char c) {
	vector<string> v;
	size_t p0 = 0;
	for ( ; ; ) {
		size_t p1 = s.find(c, p0);
		if (p1 == string::npos) {
			v.push_back(s.substr(p0));
			break;
		}
		v.push_back(s.substr(p0, p1 - p0));
		p0 = p1 + 1;
	}
	return v;
}

int parse_dist(string s) {
	size_t n = s.length();
	assert(n >= 5);
	assert(s.substr(n - 2) == "KM");
	assert(s[n - 4] == '.');
	return stoi(s.substr(0, n - 4) + s.substr(n - 3, 1)) * 100;
}

string format_dist(int d) {
	char s[20];
	sprintf(s, "%d.%dKM", d / 1000, d % 1000 / 100);
	return string(s);
}

int parse_time(string s) {
	vector<string> v = split(s, ':');
	assert(v.size() == 3);
	return stoi(v[0]) * 3600 + stoi(v[1]) * 60 + stoi(v[2]);
}

string format_time(int t) {
	char s[20];
	sprintf(s, "%d:%02d:%02d", t / 3600, t % 3600 / 60, t % 60);
	return string(s);
}

struct Runner {
	string name;
	char cat; // 'M'/'N'
	bool dq; // disqualified?
	int dist; // meters, 0 for DQ
	int time; // seconds, 0 for DQ
	string team; // may be empty

	Runner(string data) {
		vector<string> v = split(data, ',');
		name = v[0];
		cat = v[1][0];
		if (v[2] == "DQ") {
			dq = true;
			dist = time = 0;
		} else {
			dq = false;
			dist = parse_dist(v[2]);
			time = parse_time(v[3]);
		}
		if (v.size() > 4) {
			team = v[4];
			while (!team.empty() && (team.back() < 'A' || team.back() > 'Z') && team.back() != ' ') {
				team.pop_back();
			}
		}
	}

	bool operator< (const Runner & that) const {
		if (dq != that.dq) {
			return dq < that.dq;
		}
		if (dist != that.dist) {
			return dist > that.dist;
		}
		if (time != that.time) {
			return time < that.time;
		}
		return name < that.name;
	}
};

struct Team {
	string name;
	char cat; // 'M'/'N'/'S'
	bool dq; // disqualified?
	int dist; // meters, 0 for DQ
	int time; // seconds, 0 for DQ
	int gr, ci, cr; // global rank, index in category, rank in category

	Team(vector<Runner> list) {
		assert(list.size() > 0);
		sort(list.begin(), list.end());
		if (list.size() > 3) {
			if (list[0].cat == list[1].cat && list[1].cat == list[2].cat) {
				for (int i = 3; i < list.size(); ++i) {
					if (list[i].cat != list[2].cat) {
						list[2] = list[i];
						break;
					}
				}
			}
			list.erase(list.begin() + 3, list.end());
		}
		name = list[0].team;
		if (list.size() == 1) {
			cat = list[0].cat;
			dq = true;
			dist = time = 0;
		} else if (list.size() == 2) {
			if (list[0].cat == list[1].cat) {
				cat = list[0].cat;
			} else {
				cat = 'S';
			}
			dq = true;
			dist = time = 0;
		} else {
			if (list[0].cat == list[1].cat && list[1].cat == list[2].cat) {
				cat = list[0].cat;
			} else {
				cat = 'S';
			}
			if (list[2].dq) {
				dq = true;
				dist = time = 0;
			} else {
				dq = false;
				dist = list[0].dist + list[1].dist + list[2].dist;
				time = list[0].time + list[1].time + list[2].time;
			}
		}
	}

	bool operator< (const Team & that) const {
		if (dq != that.dq) {
			return dq < that.dq;
		}
		if (dist != that.dist) {
			return dist > that.dist;
		}
		if (time != that.time) {
			return time < that.time;
		}
		return name < that.name;
	}

	bool tied(const Team & that) const {
		if (dq != that.dq) {
			return false;
		}
		if (dist != that.dist) {
			return false;
		}
		if (time != that.time) {
			return false;
		}
		return true;
	}
};

int main() {
	int n;
	fi >> n >> ws;
	map<string, vector<Runner>> m; // team names to member lists
	for (int i = 0; i < n; ++i) {
		string s;
		getline(fi, s);
		Runner r(s);
		if (!r.team.empty()) {
			m[r.team].push_back(r);
		}
	}
	vector<Team> t;
	for (auto i : m) {
		t.push_back(Team(i.second));
	}
	sort(t.begin(), t.end());
	map<char, int> p;
	p['M'] = p['N'] = p['S'] = -1;
	for (int i = 0; i < t.size(); ++i) {
		if (i > 0 && t[i].tied(t[i - 1])) {
			t[i].gr = t[i - 1].gr;
		} else {
			t[i].gr = i + 1;
		}
		int j = p[t[i].cat];
		if (j < 0) {
			t[i].ci = 1;
			t[i].cr = 1;
		} else if (t[i].tied(t[j])) {
			t[i].ci = t[j].ci + 1;
			t[i].cr = t[j].cr;
		} else {
			t[i].ci = t[j].ci + 1;
			t[i].cr = t[i].ci;
		}
		if (t[i].dq) {
			fo << "DQ" << ',' << t[i].cat << ',' << t[i].name << '\n';
		} else {
			fo << t[i].gr << ',' << t[i].cat << t[i].cr << ',' << t[i].name << ',' << format_dist(t[i].dist) << ',' << format_time(t[i].time) << '\n';
		}
		p[t[i].cat] = i;
	}
}
